@@ -1,7 +1,11 @@
-import time
 import logging
+import time
 from functools import wraps
 
+from . import compat
+
+compat.patch()  # monkey-patch time.perf_counter
+
 log = logging.getLogger('amqpy')
 
 
